# Generated by Django 4.1.8 on 2023-04-27 12:29

from django.db import migrations, models

import bx_django_utils.translation


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0008_alter_connecteduniqueslugmodel1_translated_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="ValidateLengthTranslations",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "translated",
                    bx_django_utils.translation.TranslationField(
                        languages=(("de", "German"), ("en", "English")),
                        max_value_length=20,
                        min_value_length=3,
                    ),
                ),
                (
                    "translated_slug",
                    bx_django_utils.translation.TranslationSlugField(
                        additional_uniqueness=None,
                        blank=True,
                        languages=(("de", "German"), ("en", "English")),
                        max_value_length=20,
                        min_value_length=3,
                        unique=True,
                    ),
                ),
            ],
        ),
    ]
