{% load accessors %}
<table>
    <tbody>
    {% for code, lang_name in widget.languages %}
        <tr>
            <td>{{ lang_name }}</td>
            <td>
                <textarea id="id_{{ widget.name }}__{{ code }}" name="{{ widget.name }}__{{ code }}">{{ widget.value|dict_get:code }}</textarea>
            </td>
        </tr>
    {% endfor %}
    </tbody>
</table>
