# Generated by Django 4.1.7 on 2023-03-20 09:12

from django.db import migrations, models

import bx_django_utils.translation


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0005_rawtranslatedmodel_translatedslugtestmodel_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="NonUniqueTranslatedSlugTestModel",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "translated",
                    bx_django_utils.translation.TranslationField(
                        ("de-de", "en-us", "es"),
                    ),
                ),
                (
                    "translated_slug",
                    bx_django_utils.translation.TranslationSlugField(
                        ("de-de", "en-us", "es"), blank=True, unique=False
                    ),
                ),
            ],
        ),
    ]
