# Generated by Django 4.1.7 on 2023-03-22 11:31

from django.db import migrations, models

import bx_django_utils.translation


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0006_nonuniquetranslatedslugtestmodel"),
    ]

    operations = [
        migrations.CreateModel(
            name="ConnectedUniqueSlugModel1",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "translated",
                    bx_django_utils.translation.TranslationField(("de-de", "en-us", "es")),
                ),
                (
                    "translated_slug",
                    bx_django_utils.translation.TranslationSlugField(
                        ("de-de", "en-us", "es"),
                        additional_uniqueness=(
                            {
                                "app_label": "test_app",
                                "field_name": "translated_slug",
                                "model_name": "ConnectedUniqueSlugModel2",
                            },
                        ),
                        blank=True,
                        unique=True,
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="ConnectedUniqueSlugModel2",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "translated",
                    bx_django_utils.translation.TranslationField(("de-de", "en-us", "es")),
                ),
                (
                    "translated_slug",
                    bx_django_utils.translation.TranslationSlugField(
                        ("de-de", "en-us", "es"),
                        additional_uniqueness=(
                            {
                                "app_label": "test_app",
                                "field_name": "translated_slug",
                                "model_name": "ConnectedUniqueSlugModel1",
                            },
                        ),
                        blank=True,
                        unique=True,
                    ),
                ),
            ],
        ),
    ]
